<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Form Recipients /////////////////////////
// Buttons:
define('FORM_RECIPIENTS_HEADING', "Wysig Form Ontvangers");
define('FORM_RECIPIENTS_EDIT_FORM_RECIPIENTS_BTN', "Wysig Form Ontvangers");
// Console Text:
define('FORM_RECIPIENTS_FORM_PAGE', "vorm Page");
define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Jy kan meer as een ontvanger ingestel deur die skeiding van die e-pos met kommas.");
// Popup Messages:
define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "ontvanger spaar ...");
define('VIEW_FORM_TABLES_HEADING', "View Form Tables");
define('VIEW_FORM_TABLES_BTN', "View Form Tables");
define('VIEW_FORM_TABLES_SELECT_TABLE', "Kies &#39;n tafels om te sien");
define('VIEW_FORM_TABLES_FILTER_READ', "Filter lees boodskappe");
?>